@@ -62,6 +62,9 @@ FAILEDOPERATION_SHIPPERTASKNOTTORETRY = 'FailedOperation.ShipperTaskNotToRetry'
 # 查询语句解析错误。
 FAILEDOPERATION_SYNTAXERROR = 'FailedOperation.SyntaxError'
 
+# 请求标签服务限频。
+FAILEDOPERATION_TAGQPSLIMIT = 'FailedOperation.TagQpsLimit'
+
 # 日志主题已关闭。
 FAILEDOPERATION_TOPICCLOSED = 'FailedOperation.TopicClosed'
 
@@ -179,6 +182,9 @@ OPERATIONDENIED_ANALYSISSWITCHCLOSE = 'OperationDenied.AnalysisSwitchClose'
 # 通知模板已绑定告警，无法删除。
 OPERATIONDENIED_NOTICEHASALARM = 'OperationDenied.NoticeHasAlarm'
 
+# 操作低频检索不支持。
+OPERATIONDENIED_OPERATIONNOTSUPPORTINSEARCHLOW = 'OperationDenied.OperationNotSupportInSearchLow'
+
 # topic绑定了数据加工。
 OPERATIONDENIED_TOPICHASDATAFORMTASK = 'OperationDenied.TopicHasDataFormTask'
 
